@@ -1,5 +1,3 @@
-import os
-from requests import Session
 from libs3tl import Step
 
 class Load(Step.Step): 
@@ -9,7 +7,7 @@ class Load(Step.Step):
         self.step = "Lo"
         self.paramsFile = 'Load.properties'
         self.logger = 'logLoad'
-        self.logFile = self.getRelativeFile(os.getcwd() + '\../logs/Load.log')
+        self.logFile = self.getRelativeFile( '../logs/Load.log')
         
     def startup(self):
         super(Load,self).startup()
@@ -17,6 +15,6 @@ class Load(Step.Step):
     
     def doWork(self):
         pass
-    
         
         
+    
\ No newline at end of file
